@@ -673,17 +673,6 @@ func patchServerSpec(node *k3d.Node, runtime runtimes.Runtime) error {
 	node.RuntimeLabels[k3d.LabelServerAPIHost] = node.ServerOpts.KubeAPI.Host
 	node.RuntimeLabels[k3d.LabelServerAPIPort] = node.ServerOpts.KubeAPI.Binding.HostPort
 
-	// If the runtime is docker, attempt to use the docker host
-	if runtime == runtimes.Docker {
-		dockerHost := runtime.GetHost()
-		if dockerHost != "" {
-			dockerHost = strings.Split(dockerHost, ":")[0] // remove the port
-			l.Log().Tracef("Using docker host %s", dockerHost)
-			node.RuntimeLabels[k3d.LabelServerAPIHostIP] = dockerHost
-			node.RuntimeLabels[k3d.LabelServerAPIHost] = dockerHost
-		}
-	}
-
 	node.Args = append(node.Args, "--tls-san", node.RuntimeLabels[k3d.LabelServerAPIHost]) // add TLS SAN for non default host name
 
 	return nil
@@ -745,6 +734,9 @@ func NodeWaitForLogMessage(ctx context.Context, runtime runtimes.Runtime, node *
 
 	}(ctx, runtime, node, since, donechan)
 
+	// pre-building error message in case the node stops returning logs for some reason: to be enriched with scanner error
+	errMsg := fmt.Errorf("error waiting for log line `%s` from node '%s': stopped returning log lines", message, node.Name)
+
 	// Start loop to check log stream for specified log message.
 	// We're looping here, as sometimes the containers run into a crash loop, but *may* recover from that
 	// e.g. when a new server is joining an existing cluster and has to wait for another member to finish learning.
@@ -792,6 +784,10 @@ func NodeWaitForLogMessage(ctx context.Context, runtime runtimes.Runtime, node *
 
 		}
 
+		if e := scanner.Err(); e != nil {
+			errMsg = fmt.Errorf("%v: %w", errMsg, e)
+		}
+
 		out.Close() // no more input on scanner, but target log not yet found -> close current logreader (precautionary)
 
 		// we got here, because the logstream ended (no more input on scanner), so we check if maybe the container crashed
@@ -806,7 +802,7 @@ func NodeWaitForLogMessage(ctx context.Context, runtime runtimes.Runtime, node *
 			break
 		}
 	}
-	return fmt.Errorf("error waiting for log line `%s` from node '%s': stopped returning log lines", message, node.Name)
+	return errMsg
 }
 
 // NodeFilterByRoles filters a list of nodes by their roles
